pycocoa.apps

Package pycocoa :: Module apps |
[frames] | no frames]

# Module apps

Types App and Tile, wrapping ObjC `NSApplication` and `NSDocktile`.

Version: 23.12.28

Classes
| App Python `App` Type, wrapping an ObjC `NSApplication`.
| Tile Dock tile for an App, wrapping an ObjC `NSDockTile`.

Functions
app_title(title) Get/set the app title. |
ns2App(ns) Get the App instance from an `NSApplication` or an `NSNotification` instance. |

Variables
| __all__ = `_ALL_LAZY.apps`
| NSApplicationDelegate = `<pycocoa.utils.module_property_RO obje`...``

Function Details

### app_title(title) |
Get/set the app title. Parameters: `title` - New title (`str`). Returns: Previous title (`str`).

### ns2App(ns) |
Get the App instance from an `NSApplication` or an `NSNotification` instance. Parameters: `ns` - The ObjC instance (`NS...`). Returns: The app instance (App). Raises: `RuntimeError` - App mismatch. `TypeError` - Invalid ns type.

Variables Details

  ### NSApplicationDelegate Value:
      <pycocoa.utils.module_property_RO object at 0x7fd608434a50>